@@ -30,10 +30,13 @@
 
 #include <libxfce4util/xfce-debug.h>
 
-#define STR_IS_EMPTY(str) ((str) == NULL || *(str) == '\0')
-
 G_BEGIN_DECLS
 
+static inline gboolean xfce_str_is_empty (const gchar *str)
+{
+  return str == NULL || *str == '\0';
+}
+
 const gchar* xfce_version_string (void) G_GNUC_PURE;
 
 const gchar* xfce_get_homedir    (void) G_GNUC_PURE;
@@ -82,19 +85,20 @@ xfce_get_userfile (const gchar *first_element, ...)
 
 #endif
 
-gchar* xfce_gethostname        (void) G_GNUC_MALLOC;
+gchar* xfce_gethostname                      (void) G_GNUC_MALLOC;
 
-gchar* xfce_expand_variables   (const gchar *command,
-                                gchar      **envp) G_GNUC_MALLOC;
+gchar* xfce_expand_variables                 (const gchar  *command,
+                                              gchar       **envp) G_GNUC_MALLOC;
 
-void   xfce_append_quoted      (GString     *string,
-                                const gchar *unquoted);
+void   xfce_append_quoted                    (GString      *string,
+                                              const gchar  *unquoted);
 
-gchar* xfce_expand_field_codes (const gchar *command,
-                                const gchar *icon,
-                                const gchar *name,
-                                const gchar *uri,
-                                gboolean     requires_terminal) G_GNUC_MALLOC;
+gchar* xfce_expand_desktop_entry_field_codes (const gchar  *command,
+                                              GSList       *uri_list,
+                                              const gchar  *icon,
+                                              const gchar  *name,
+                                              const gchar  *uri,
+                                              gboolean      requires_terminal) G_GNUC_MALLOC;
 
 G_END_DECLS
 
